
--[[
Title: GUI Test
Author: Carl Reed
Date: 10/14 2013
Purpose: Test to see if we can get over 15~20 jpegs translated/scaled, decoded and displayed per second. (From a fake network source).
License: MIT-LICENSE -

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

require "scripts/aliases"
require "scripts/helpers"
local socket = require "socket"


function love.load()
	server, serverErr = socket.tcp()
	bind, bindErr = server:bind('127.2.3.4',1234)
	listen, listenErr = server:listen()
	connection,connErr = server:accept()
	heartbeat = 0
	lastSent = 0
end

function love.update(dt)
	heartbeat = heartbeat+dt
	if connection then
		if math.floor(heartbeat)>lastSent then
			lastSent = math.floor(heartbeat)
			connection:send(tostring(heartbeat))
		end
	end
end

function love.draw()
	if bindErr then lg.print('bind error: ' .. bindErr,20,20) end
	if listenErr then lg.print('listen error: ' .. listenErr,20,40) end
	if connErr then lg.print('connection error: ' .. connErr,20,40) end
	if closed then lg.print('closed connection', 20,100) end
	
	if bind then lg.print('bound',20,60) end
	if listen then lg.print('listening',20,80) end
	if connection and not closed then lg.print('connected', 20,100) end
	if lastSent~=0 then lg.print('last sent: ' .. tostring(lastSent), 20, 120) end
end

-------------------------------

function love.keypressed(k,uc)
	if key=='c' then connection:close() closed = true end
end



